/*
 * FILE --- my_observer.hh
 *
 * PURPOSE --- Header file for a class that provides an example of usage
 * of the Linear State Observer utility for Single-Input-Single-Output (SISO) 
 * plants.
 *
 */

// Prevent Multiple Inclusion
#ifndef MY_OBSERVER_HH
#define MY_OBSERVER_HH

// Include Files
#include <stdlib.h>
#include "observer.hh"

// Local Definitions

class MY_OBSERVER: public OBSERVER
{
public:

  // Constructor
  MY_OBSERVER(int _plant_order, double _sample_time = 0.01);

  // Destructor
  ~MY_OBSERVER();

  // Main function to be called from outside. It does not return any value.
  // Instead, the array plant_state from the base class contains the current
  // estimated states.
  void observe(const double _input_to_plant, const double _output_of_plant);

  // Conveniance variable to hold the error b/n actual and estimated output
  double output_error; 

private:
  // Plant parameters of my particular plant
  double a11, a12, a21, a22; // 2x2 matrix A
  double b1, b2;             // 2x1 vector B
  double c1, c2;             // 1x2 vector C 

  // Overload DERIV function of RK4_SIM (OBSERVER) for the simulator
  // to implement the dynamics of my plant
  inline void DERIV(const double t, const double *x, 
                    const double *u, double *xdot);
};

#endif // MY_OBSERVER_HH
