 /*
 * FILE --- plant_sim.hh
 *
 * PURPOSE --- Header file for a class that provides a simulation of an 
 * example plant whose state is to be observed using the Linear State 
 * Observer utility for Single-Input-Single-Output (SISO) plants.
 * In actual implementations the signal generated from this example will
 * be measured from actual systems.
 *
 */

// Prevent Multiple Inclusion
#ifndef PLANT_SIM_HH
#define PLANT_SIM_HH

// Include Files
#include <math.h>
#include "rk4_sim.hh"

class PLANT_SIM : public RK4_SIM
{
public:

  // Constructor
  PLANT_SIM (double samp_time = 0.005,
	     double _initial_time = 0.0, 
	     double *_initial_state = NULL);

  // Destructor
  ~PLANT_SIM ();
  
  // Overload DERIV function of RK4_SIM for simulating plant dynamics
  inline void DERIV(const double t, const double *x, 
		    const double *u, double *xdot);
  
  // the Simulation routine
  void simulate ();
  
  double sampling_period;  // Sampling time
  double plant_output;     // Conveniance variable to hold the plant output
  
private:
  // Plant parameters
  double a11, a12, a21, a22; // 2x2 matrix A
  double b1, b2;             // 2x1 vector B
  double c1, c2;             // 1x2 vector C 
};

#endif // PLANT_SIM_HH


